@@ -103,7 +103,11 @@ update_position()
 	label_msg = (GtkLabel *)lookup_widget(window1, "label51");
 	gtk_label_set_label (label_msg, _("Connecting..."));
 
+#if GLIB_CHECK_VERSION(2,34,0)
+	if (!g_thread_new("friends thread", &update_position_thread, (gpointer) NULL) != 0)
+#else
 	if (!g_thread_create(&update_position_thread, NULL, FALSE, NULL) != 0)
+#endif
 		g_warning("### can't create friend thread\n");
 
 	return TRUE;
@@ -468,7 +472,11 @@ register_nick()
 	label_msg = (GtkLabel *)lookup_widget(window1, "label62");
 	gtk_label_set_text (label_msg, _("Connecting..."));
 
+#if GLIB_CHECK_VERSION(2,34,0)
+	if (!g_thread_new("register nick thread", &register_nick_thread, (gpointer) NULL) != 0)
+#else
 	if (!g_thread_create(&register_nick_thread, NULL, FALSE, NULL) != 0)
+#endif
 		g_warning("### can't create register_nick() thread\n");
 
 	return 0;
@@ -696,7 +704,11 @@ send_message(gpointer user_data)
 
 	postdata = create_msg_postdata(m);
 
+#if GLIB_CHECK_VERSION(2,34,0)
+	if (!g_thread_new("Mission thread", &thread_send_message, postdata) != 0)
+#else
 	if (!g_thread_create(&thread_send_message, postdata, FALSE, NULL) != 0)
+#endif
 		g_warning("### can't create mission thread\n");
 
 	return TRUE;
