@@ -686,7 +686,11 @@ geo_photo_close_dialog_photo_correlate()
 	gtk_widget_show(dialog_geocode_result);
 	gtk_widget_hide(dialog_photo_correlate);
 
+#if GLIB_CHECK_VERSION(2,34,0)
+	g_thread_new("geocode thread", geocode_thread, (gpointer) NULL);
+#else
 	g_thread_create(geocode_thread, NULL, FALSE, NULL);
+#endif
 }
 
 
