@@ -31,16 +31,16 @@ int global_y = 515;
 int global_zoom = 3;
 int global_zoom_max = 20;
 int global_detail_zoom = 0;
-		
-int mouse_dx = 0; 
+
+int mouse_dx = 0;
 int mouse_dy = 0;
-		
+
 int global_drawingarea_width  = 0;
 int global_drawingarea_height = 0;
 
-int global_speed_unit	= 0;	
-int global_alt_unit	= 0;	
-int global_latlon_unit	= 0;	
+int global_speed_unit	= 0;
+int global_alt_unit	= 0;
+int global_latlon_unit	= 0;
 
 
 tangogps_gps_data_t *gpsdata = NULL;
@@ -70,7 +70,7 @@ int		global_repo_cnt = 0;
 int		global_repo_nr = 1;
 GSList 		*global_repo_list = NULL;
 GSList		*global_curr_repo = NULL;
-GConfClient	*global_gconfclient = NULL;
+GSettings	*global_settings = NULL;
 
 gboolean	global_infopane_visible = FALSE;
 gboolean	global_landscape;
