@@ -5,11 +5,10 @@
 
 #include <gtk/gtk.h>
 #include <glade/glade.h>
-#include <gconf/gconf-client.h>
 
 #define MSG_SEND_URL "http://tangogps.org/friends/msg_send.php"
 
-#define GCONF "/apps/" PACKAGE
+#define SCHEMA "org.foxtrotgps"
 #define TILESIZE 256
 #define MAP_PAGE 0
 #define FRIENDS_PAGE 1
@@ -152,7 +151,7 @@ extern gchar		*global_curr_reponame;
 extern int		global_repo_cnt;
 extern int		global_repo_nr;
 extern GSList	 	*global_repo_list, *global_curr_repo;
-extern GConfClient	*global_gconfclient;
+extern GSettings	*global_settings;
 
 extern gboolean		global_infopane_visible;
 extern gboolean		global_landscape;
