@@ -738,7 +738,11 @@ cb_gpsd_data(GIOChannel *src, GIOCondition condition, gpointer data)
 	if (!libgps_initialized)
 		return FALSE;
 
+#if GPSD_API_MAJOR_VERSION >= 7 /* API change. gpsd version 3.18 and subsequent. */
+	ret = gps_read(&libgps_gpsdata, NULL, 0);
+#else
 	ret = gps_read(&libgps_gpsdata);
+#endif
 	/* Note that gps_read() will never actually return 0
 	   (zero-length reads are converted internally to a -1 return,
 	    since they mean that the connection to the daemon has closed),
@@ -832,7 +836,11 @@ get_gps()
 		libgps_initialized = FALSE;
 	}
 
+#if GLIB_CHECK_VERSION(2,34,0)
+	g_thread_new("gps thread", &get_gps_thread, (gpointer)NULL);
+#else
 	g_thread_create(&get_gps_thread, NULL, FALSE, NULL);
+#endif
 }
 
 static void *
