@@ -25,3 +25,6 @@ get_pois();
 
 void
 show_poi_detail();
+
+double
+parse_degrees(const char *s);
