@@ -864,7 +864,11 @@ void fetch_yournavigation_track(GtkWidget *widget, char *start, char *end)
 	dialog10 = widget;
 
 	url = g_strdup_printf("http://www.yournavigation.org/api/1.0/gosmore.php?format=kml&flat=%s&flon=%s&tlat=%s&tlon=%s&v=motorcar&fast=1&layer=mapnik",startlatstr, startlonstr, endlatstr, endlonstr);
+#if GLIB_CHECK_VERSION(2,34,0)
+	if (!g_thread_new("fetch track thread", &fetch_track_thread, (void *)url) != 0)
+#else
 	if (!g_thread_create(&fetch_track_thread, (void *)url, FALSE, NULL) != 0)
+#endif
 		g_warning("### can't create route thread\n");
 }
 
@@ -928,7 +932,11 @@ void fetch_openrouteservice_track(GtkWidget *widget, char *start, char *end)
 	urlAndRequest[0] = url;
 	urlAndRequest[1] = request;
 
+#if GLIB_CHECK_VERSION(2,34,0)
+	if (!g_thread_new("fetch open route thread", &fetch_openrouteservice_track_thread, (void *)urlAndRequest) != 0)
+#else
 	if (!g_thread_create(&fetch_openrouteservice_track_thread, (void *)urlAndRequest, FALSE, NULL) != 0)
+#endif
 		g_warning("### can't create route thread\n");
 }
 
